skhubness.neighbors.KernelDensity
=================================

.. currentmodule:: skhubness.neighbors

.. autoclass:: KernelDensity

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~KernelDensity.__init__
      ~KernelDensity.fit
      ~KernelDensity.get_params
      ~KernelDensity.sample
      ~KernelDensity.score
      ~KernelDensity.score_samples
      ~KernelDensity.set_params
   
   

   
   
   